<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Travel Base Pro
 * @since Travel Base Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'travel_base_pro_service_section', array(
	'title'             => esc_html__( 'Services','travel-base-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'travel-base-pro' ),
	'panel'             => 'travel_base_pro_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'travel_base_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Base_Pro_Switch_Control( $wp_customize, 'travel_base_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_service_section',
	'on_off_label' 		=> travel_base_pro_switch_options(),
) ) );

// Service content type control and setting
$wp_customize->add_setting( 'travel_base_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'travel_base_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_base_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_base_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travel-base-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-base-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-base-pro' ),
	),
) );

for ( $i = 1; $i <= 3; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'travel_base_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Travel_Base_Pro_Icon_Picker( $wp_customize, 'travel_base_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'travel-base-pro' ), $i ),
		'section'           => 'travel_base_pro_service_section',
		'active_callback'	=> 'travel_base_pro_is_service_section_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_base_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_base_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Chooser( $wp_customize, 'travel_base_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-base-pro' ), $i ),
		'section'           => 'travel_base_pro_service_section',
		'choices'			=> travel_base_pro_page_choices(),
		'active_callback'	=> 'travel_base_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_base_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_base_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Chooser( $wp_customize, 'travel_base_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-base-pro' ), $i ),
		'section'           => 'travel_base_pro_service_section',
		'choices'			=> travel_base_pro_post_choices(),
		'active_callback'	=> 'travel_base_pro_is_service_section_content_post_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'travel_base_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travel_Base_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_base_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'travel_base_pro_service_section',
			'active_callback' => 'travel_base_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_base_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'travel_base_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travel_Base_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_base_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-base-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travel-base-pro' ),
	'section'           => 'travel_base_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_base_pro_is_service_section_content_category_enable'
) ) );
